==> botanypots-fabric-1.21.1-21.1.3-sources.jar: net/darkhax/botanypots/common/addons/jei/crop/CropInfo.java <==
package net.darkhax.botanypots.common.addons.jei.crop;

import net.darkhax.botanypots.common.api.data.context.BotanyPotContext;
import net.darkhax.botanypots.common.api.data.context.DisplayContext;
import net.darkhax.botanypots.common.api.data.itemdrops.ItemDropProvider;
import net.minecraft.class_1799;
import net.minecraft.class_1856;
import net.minecraft.class_2960;
import java.util.ArrayList;
import java.util.List;

public final class CropInfo {

    private final BotanyPotContext context;
    private final class_2960 id;
    private final class_1856 seed;
    private final class_1856 soil;
    private final int growthTime;
    private final List<ItemDropProvider> drops;
    private final List<class_1799> inventory = new ArrayList<>(15);

    public CropInfo(class_2960 id, class_1856 seed, class_1856 soil, int growthTime, List<ItemDropProvider> drops) {
        this.context = new DisplayContext(this.inventory);
        this.id = id;
        this.seed = seed;
        this.soil = soil;
        this.growthTime = growthTime;
        this.drops = drops;
    }

    public BotanyPotContext context() {
        return context;
    }

    public class_2960 id() {
        return id;
    }

    public class_1856 seed() {
        return seed;
    }

    public class_1856 soil() {
        return soil;
    }

    public int growthTime() {
        return growthTime;
    }

    public List<ItemDropProvider> drops() {
        return drops;
    }

    public List<class_1799> inventory() {
        return this.inventory;
    }
}

==> botanypots-fabric-1.21.1-21.1.32-sources.jar: net/darkhax/botanypots/common/addons/jei/crop/CropInfo.java <==
package net.darkhax.botanypots.common.addons.jei.crop;

import net.darkhax.botanypots.common.api.context.BotanyPotContext;
import net.darkhax.botanypots.common.api.context.DisplayContext;
import net.darkhax.botanypots.common.api.data.itemdrops.ItemDropProvider;
import net.minecraft.class_1799;
import net.minecraft.class_1856;
import net.minecraft.class_2960;
import java.util.ArrayList;
import java.util.List;

public final class CropInfo {

    private final BotanyPotContext context;
    private final class_2960 id;
    private final class_1856 seed;
    private final class_1856 soil;
    private final int growthTime;
    private final List<ItemDropProvider> drops;
    private final List<class_1799> inventory = new ArrayList<>(15);

    public CropInfo(class_2960 id, class_1856 seed, class_1856 soil, int growthTime, List<ItemDropProvider> drops) {
        this.context = new DisplayContext(this.inventory);
        this.id = id;
        this.seed = seed;
        this.soil = soil;
        this.growthTime = growthTime;
        this.drops = drops;
    }

    public BotanyPotContext context() {
        return context;
    }

    public class_2960 id() {
        return id;
    }

    public class_1856 seed() {
        return seed;
    }

    public class_1856 soil() {
        return soil;
    }

    public int growthTime() {
        return growthTime;
    }

    public List<ItemDropProvider> drops() {
        return drops;
    }

    public List<class_1799> inventory() {
        return this.inventory;
    }
}
